@@ -16,13 +16,13 @@
 #include <QGeoPositionInfo>
 #include <QGeoCoordinate>
 
-QTM_USE_NAMESPACE
+QTM_USE_NAMESPACE;
 
 class StationDetail : public QWidget {
-	Q_OBJECT;
+    Q_OBJECT;
 public:
-	StationDetail(Station * station, QWidget *parent = 0);
-	virtual ~StationDetail();
+    StationDetail(Station * station, QWidget *parent = 0);
+    virtual ~StationDetail();
 };
 
 #endif /* STATIONDETAIL_H_ */
